@@ -2,8 +2,8 @@
 
 __author__ = 'Yoni Pacheco'
 __email__ = 'aniversarioperu1@gmail.com'
-__version__ = '0.0.1'
+__version__ = '0.0.2'
 
-from .bot import Twitterbot
+from twitterbot.bot import TwitterBot
 
-__all__ = ['Twitterbot']
+__all__ = ['TwitterBot']
